@@ -264,6 +264,7 @@ sub refresh {
 			'make',
 			'make clean',
 			'make dist',
+			'make disttest',
 			'make manifest',
 			'make realclean',
 			'make test',
@@ -279,6 +280,7 @@ sub refresh {
 			'./Build',
 			'./Build clean',
 			'./Build dist',
+			'./Build disttest',
 			'./Build manifest',
 			'./Build realclean',
 			'./Build test',
